/***************************************************************************
                                diagrams.h
                              --------------
    begin                : Sat Aug 23 2003
    copyright            : (C) 2003 by Michael Margraf
    email                : michael.margraf@alumni.tu-berlin.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DIAGRAMS_H
#define DIAGRAMS_H

// This header file includes the header files of all diagrams.

#include "diagram.h"

#include "rectdiagram.h"
#include "polardiagram.h"
#include "smithdiagram.h"
#include "tabdiagram.h"
#include "psdiagram.h"
#include "rect3ddiagram.h"
#include "curvediagram.h"

#endif
